pymodaq_plugins_picoquant (Picoquant)
#####################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_picoquant.svg
   :target: https://pypi.org/project/pymodaq_plugins_picoquant/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/CEMES-CNRS/pymodaq_plugins_picoquant/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/CEMES-CNRS/pymodaq_plugins_picoquant

PyMoDAQ plugin for Picoquant instruments (TimeHarp260, ...)


Authors
=======

* Sebastien J. Weber

Instruments
===========
Below is the list of instruments included in this plugin


Viewer1D
++++++++

* **TH260**: Timeharp TH260 for *photon counting* and *time tagging*

